@@ -41,8 +41,8 @@ side_plot = function(data,
 
   gdata = gdata %>%
     group_by(facet_x) %>%
-    mutate(sides = any(y >= 0) + any(y < 0),
-           y_range = diff(range(c(y[is.finite(y)], 0))) * ifelse(y >= 0, 1, -1),
+    mutate(sides = any(y >= 0, na.rm = TRUE) + any(y < 0, na.rm = TRUE),
+           y_range = diff(range(c(y[is.finite(y)], 0))) * dplyr::coalesce(ifelse(y >= 0, 1, -1), 1),
            y_rescaled_range = y_range * ifelse(sides < 2, rescale_y, 2 * rescale_y - 1),
            y_text_nudge = y_rescaled_range / 60,
            y_axis_nudge = (y_rescaled_range - y_range) / sides) %>%
@@ -70,7 +70,7 @@ side_plot = function(data,
     ylab(NULL) +
     theme(panel.grid.major.y = element_blank(),
           panel.grid.major.x = element_line(colour = "grey85",
-                                            size = if (size > 16) 0.8 else 0.2),
+                                            linewidth = if (size > 16) 0.8 else 0.2),
           axis.line.x = element_blank(),
           strip.placement = "outside")
   quick_facet(g, strip.position = "bottom", scales = "free_x", nrow = 1) +
